/**
 * @jest-environment jsdom
 */

// Copyright (c) 2023 Tudor Stanciu

import axios from "axios";
import { TuitioClient } from "../client";
import { fetch } from "../state";
import { localStorage } from "@flare/js-utils";
import { storageKeys } from "../constants";

const { setItem } = localStorage;

jest.mock("axios");

test("Tuitio client: error if account logout is called before login", async () => {
  (axios.request as jest.Mock).mockResolvedValue({
    data: {
      result: { userId: 0, userName: "tuitio.user", logoutDate: new Date() },
      error: null
    }
  });

  const client = new TuitioClient("https://test.com/api");
  const logoutResult = await client.logout();
  expect(logoutResult.result).toBeNull();
  expect(logoutResult.error).toBe("UNAUTHENTICATED");
});

test("Tuitio client: successfully account logout", async () => {
  (axios.request as jest.Mock).mockResolvedValue({
    data: {
      result: { userId: 0, userName: "tuitio.user", logoutDate: new Date() },
      error: null
    }
  });

  const client = new TuitioClient("https://test.com/api");
  const authData = { token: "mocked-token", validUntil: new Date(), userName: "tuitio.user" };
  setItem(storageKeys.AUTH_DATA, authData);

  const logoutResult = await client.logout();

  expect(logoutResult.result?.userId).toBe(0);
  expect(logoutResult.result?.userName).toBe("tuitio.user");
  expect(logoutResult.error).toBeNull();

  const storage = fetch();
  expect(storage).toBeDefined();
  expect(storage.token).toBeNull();
  expect(storage.validUntil).toBeNull();
  expect(storage.userName).toBeNull();
});
